diff --git a/sites/all/modules/unl/unl_migration.php b/sites/all/modules/unl/unl_migration.php
index 2238bff99b7209d7e2a107b1d306d86ef5a2de19..8d27a059a7f7dfae7e29d571341ad4c3ff21e781 100644
--- a/sites/all/modules/unl/unl_migration.php
+++ b/sites/all/modules/unl/unl_migration.php
@@ -814,8 +814,8 @@ class Unl_Migration_Tool
             $headers[$headerKey] = trim($headerValue);
         }
         
-        // don't copy files greater than 100MB in size
-        if (isset($headers['Content-Length']) && $headers['Content-Length'] > (100 * 1024 * 1024)) {
+        // don't copy files greater than 10MB in size
+        if (isset($headers['Content-Length']) && $headers['Content-Length'] > (10 * 1024 * 1024)) {
             $size = floor($headers['Content-Length'] / (1024 * 1024)); 
             $this->_log("The file at $url is $size MB!  Ignoring.");
             $content = '';